@@ -24,13 +24,18 @@ CROSSMARK = "✘"
 
 
 def entrypoint(project, timeout):
-    lock = CaptainHook()
+    captainhook = CaptainHook()
     if timeout:
-        lock.set_timeout(timeout)
+        captainhook.set_timeout(timeout)
 
-    stop_if_master_locked(project, lock)
+    stop_if_master_locked(project, captainhook)
 
     pr = select_pr(project)
+
+    print(f"\nHai selezionato: \n{check_pr_status(project, pr)}")
+    if not prompt_utils.ask_confirm("Vuoi continuare il merge?", default=False):
+        sys.exit(0)
+
     branch_name = pr.head.ref
     youtrack_id = youtrack.get_card_from_name(branch_name)
 
@@ -65,7 +70,7 @@ def entrypoint(project, timeout):
         "Vuoi bloccare staging? (Necessario se bisogna testare su staging)",
         default=False,
     ):
-        lock.lock_project(project)
+        captainhook.lock_project(project, "staging")
 
     if youtrack_id:
         logger.info("Aggiorno lo stato della card su youtrack...")
@@ -94,9 +99,7 @@ def select_pr(project):
 
     with Halo(text="Loading pull requests...", spinner="dots", color="magenta"):
         choices = [
-            {"name": choice(project, pr), "value": pr}
-            for pr in github.get_list_pr(project)
-            if pr.mergeable
+            {"name": pr.title, "value": pr} for pr in github.get_list_pr(project)
         ]
     if choices:
         return prompt_utils.ask_choices("Seleziona PR: ", choices)
@@ -107,9 +110,9 @@ def select_pr(project):
     sys.exit(-1)
 
 
-def stop_if_master_locked(project, lock):
+def stop_if_master_locked(project, captainhook):
     try:
-        request = lock.status(project, "staging")
+        request = captainhook.status(project, "staging")
     except Exception:
         logger.error("Impossibile contattare CaptainHook, stai usando la VPN?")
         sys.exit(-1)
@@ -141,7 +144,7 @@ def check_migrations_merge(pr):
             sys.exit(-1)
 
 
-def choice(project, pr):
+def check_pr_status(project, pr):
     build_status = CHECKMARK
     reviews = CHECKMARK
     if pr.mergeable_state == "blocked":
